@@ -701,10 +701,7 @@ Adapt_buffer_convert(dc1394video_frame_t *in, dc1394video_frame_t *out)
     if (out->total_bytes>out->allocated_image_bytes) {
         free(out->image);
         out->image=(uint8_t*)malloc(out->total_bytes*sizeof(uint8_t));
-        if (out->image)
-            out->allocated_image_bytes = out->total_bytes*sizeof(uint8_t);
-        else
-            out->allocated_image_bytes = 0;
+        out->allocated_image_bytes=out->total_bytes;
     }
 
     // Copy padding bytes:
@@ -877,10 +874,7 @@ Adapt_buffer_stereo(dc1394video_frame_t *in, dc1394video_frame_t *out)
     if (out->total_bytes>out->allocated_image_bytes) {
         free(out->image);
         out->image=(uint8_t*)malloc(out->total_bytes*sizeof(uint8_t));
-        if (out->image)
-            out->allocated_image_bytes = out->total_bytes*sizeof(uint8_t);
-        else
-            out->allocated_image_bytes = 0;
+        out->allocated_image_bytes=out->total_bytes;
     }
 
     // Copy padding bytes:
@@ -904,7 +898,7 @@ dc1394_deinterlace_stereo_frames(dc1394video_frame_t *in, dc1394video_frame_t *o
         switch (method) {
         case DC1394_STEREO_METHOD_INTERLACED:
             err=Adapt_buffer_stereo(in,out);
-            dc1394_deinterlace_stereo(in->image, out->image, out->size[0], out->size[1]);
+            dc1394_deinterlace_stereo(in->image, out->image, in->size[0], in->size[1]);
             break;
         case DC1394_STEREO_METHOD_FIELD:
             err=Adapt_buffer_stereo(in,out);
