@@ -424,8 +424,6 @@ int dc_init()
     dc1394error_t err;
 
     d = dc1394_new ();
-    if (!d)
-        return 1;
     err=dc1394_camera_enumerate (d, &list);
     DC1394_ERR_RTN(err,"Failed to enumerate cameras");
 
@@ -515,12 +513,10 @@ int v4l_open(char *device)
             return -1;
         }
         /* Read vloopback version */
-        if (fgets(buffer, 255, vloopbacks)==NULL)
-            perror("Failed to read");
+        fgets(buffer, 255, vloopbacks);
         printf("%s", buffer);
         /* Read explanation line */
-        if (fgets(buffer, 255, vloopbacks)==NULL)
-            perror("Failed to read");
+        fgets(buffer, 255, vloopbacks);
         while (fgets(buffer, 255, vloopbacks)) {
             if (strlen(buffer)>1) {
                 buffer[strlen(buffer)-1]=0;
